@@ -180,7 +180,7 @@ class Instrument(str):
         }
 
     # ---------------------------------------
-    def create_position(self, entry_price, stop_loss, quantity=None, pos_type=PositionType.CO):
+    def create_position(self, entry_price, stop_loss, quantity=None, pos_type=PositionType.CO) -> Position:
         """
         return trade if all the conditions are met
         :param pos_type: position variety. ex MIS, CO, CNC. default to MIS. Possible types are defined in enums.PositionType
@@ -203,7 +203,7 @@ class Instrument(str):
                             _variety=pos_type)
 
     # ---------------------------------------
-    def open_position(self, position, **kwargs):
+    def open_position(self, position: Position, **kwargs):
         if position.active or self._position is not None:
             raise Exception("Position can't be opened because there is an active open position")
 
@@ -226,17 +226,18 @@ class Instrument(str):
                                           pos_type=trade.variety,
                                           initial_stop=trade.stop, **opts)
                     position._broker_order_id = order_id
-                    if not self.parent.blotter_args["dbskip"]:
-                        position.save()
+                    self.save_to_db(position)
+
             self.bot.send_order(position, "**ENTER** #" + self, callback=callback)
 
     # ---------------------------------------
-    def close_position(self, position, **kwargs):
+    def close_position(self, position: Position, **kwargs):
+        if self._position is not None and position is self._position:
+            self._position = None
         if not position.active:
             raise Exception("Position can't be closed because the status is inactive")
         position.close_position()
         self.parent.risk_assessor.exit_position(position)
-        self._position = None
 
         txn_type = "SELL" if position.direction == "LONG" else "BUY"  # EXIT
         if self.parent.backtest:
@@ -248,10 +249,10 @@ class Instrument(str):
                     self.order(txn, trade.quantity, pos_type=trade.variety, **opts, **args)
                 else:
                     self.cancel_order(trade.broker_order_id)
+
             self.bot.send_order(position, "**EXIT** #" + self, callback=callback)
 
-        if not self.parent.blotter_args["dbskip"]:
-            position.save()
+        self.save_to_db(position)
 
     # ---------------------------------------
     def order(self, txn_type, quantity, **kwargs):
@@ -487,6 +488,10 @@ class Instrument(str):
         pos = [self._position] if self._position is not None else []
         return pos
 
+    # ---------------------------------------
+    def set_position(self, position):
+        self._position = position
+
     # ---------------------------------------
     def get_portfolio(self):
         """Get portfolio data for the instrument
@@ -668,6 +673,11 @@ class Instrument(str):
         """
         return self.parent._log_signal(self, signal)
 
+    # ---------------------------------------
+    def save_to_db(self, obj):
+        if not self.parent.blotter_args["dbskip"]:
+            obj.save()
+
     # ---------------------------------------
     @property
     def bars(self):
